@@ -141,6 +141,12 @@ DESeqDataSet <- function(se, design, ignoreRank=FALSE) {
     }
   }
   if (is.null(assayNames(se)) || assayNames(se)[1] != "counts") {
+    # check if "counts" are in another assay spot:
+    if (length(assayNames(se)) > 1) {
+      if ("counts" %in% assayNames(se)[-1]) {
+        stop("'counts' assay is not the first in assays list, re-arrange so that 'counts' is first")
+      }
+    }
     message("renaming the first element in assays to 'counts'")
     assayNames(se)[1] <- "counts"
   }
@@ -232,8 +238,8 @@ DESeqDataSet <- function(se, design, ignoreRank=FALSE) {
       if (msgCenterScale) {
         message("  the design formula contains one or more numeric variables that have mean or
   standard deviation larger than 5 (an arbitrary threshold to trigger this message).
-  it is generally a good idea to center and scale numeric variables in the design
-  to improve GLM convergence.")
+  Including numeric variables with large mean can induce collinearity with the intercept.
+  Users should center and scale numeric variables in the design to improve GLM convergence.")
       }
     }
 
@@ -401,6 +407,7 @@ DESeqDataSetFromHTSeqCount <- function( sampleTable, directory=".", design, igno
 #' @export
 DESeqDataSetFromTximport <- function(txi, colData, design, ...) 
 {
+  stopifnot(is(txi, "list"))
   counts <- round(txi$counts)
   mode(counts) <- "integer"
   object <- DESeqDataSetFromMatrix(countData=counts, colData=colData, design=design, ...)
@@ -486,14 +493,19 @@ processTximeta <- function(se) {
   mode(assay(se)) <- "integer"
   stopifnot("countsFromAbundance" %in% names(metadata(se)))
   cfa <- metadata(se)$countsFromAbundance
-  stopifnot(cfa %in% c("no","scaledTPM","lengthScaledTPM"))  
+  stopifnot(cfa %in% c("no","scaledTPM","lengthScaledTPM"))
+  lengthPresent <- "length" %in% assayNames(se)
   if (cfa %in% c("scaledTPM","lengthScaledTPM")) {
     message("using just counts from tximeta")
   } else {
-    message("using counts and average transcript lengths from tximeta")
-    stopifnot(all(assays(se)$length > 0))
-    anms <- assayNames(se)
-    assayNames(se)[anms == "length"] <- "avgTxLength"
+    if (lengthPresent) {
+      message("using counts and average transcript lengths from tximeta")
+      stopifnot(all(assays(se)$length > 0))
+      anms <- assayNames(se)
+      assayNames(se)[anms == "length"] <- "avgTxLength"
+    } else {
+      message("length assay is missing, using original counts without length adjustment")
+    }
   }
   return(se)
 }
